AuthmatechResult class

Data classes

Constructors

AuthmatechResult({required String authmatechCode, required String MNOID, required String errorCode, required String errorDesc})

Properties

authmatechCode String
final
errorCode String
final
errorDesc String
final
hashCode int
The hash code for this object.
no setterinherited
MNOID String
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited