AuthmatechSdkFlutter class
Authmatech SDK Flutter plugin.
Provides identity verification using cellular data on Android and iOS.
Constructors
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
getPlatformVersion(
) → Future< String?> -
getSimplifiedResponse(
String url) → Future< AuthmatechResult> - Gets a simplified response from the URL using cellular data connection
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
openWithDataCellular(
String url, bool debug) → Future< Map> - Opens a URL with cellular data connection
-
openWithDataCellularAndAccessToken(
String url, String? accessToken, bool debug) → Future< Map> - Opens a URL with cellular data connection using an access token
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited